<?php
/*
    access.class.php - contains ICM_Access class description
*/

require_once "table.class.php"; //ICM_DB description
require_once "group.class.php"; //TBL_Group description
require_once "user.class.php";  //TBL_User description

class ICM_Access
{
    var $login;     //user login
    var $pass;      //user password, md5 crypted
    var $ip;        //user ip, when logged in
    var $browser;   //user browser agent when logged in
    /* methods:
    bool ICM_Access()
    bool login(string login, string pass, int &errno)
    bool logout()
    bool is_authorized(int &errno)
    bool is_allowed(int owner, string attr, string action)
    */

/*
    constructor
    receives nothing
    returnes true
*/
    function ICM_Access()
    {
        $this->login=getVar($_SESSION, 'ses_login');
        $this->pass=getVar($_SESSION, 'ses_pass');
        $this->ip=getVar($_SESSION, 'ses_ip');
        $this->browser=getVar($_SESSION, 'ses_browser');
        return true;
    }

/*
    logges user if given login and passwords are correct
    receives user login and password, variable for erro number record
    returnes true is succeed, false otherwise plus write error number to $errno
*/
    function login($login, $pass, &$errno, $remember = false)
    {
        $User=new TBL_User;
        $Group=new TBL_Group;

        /*
            get user info
        */
        $user=$User->id_by_login($login);               //user ID
        $user_login=$User->getValue($user, 'login');    //user login
        $user_pass=$User->getValue($user, 'pass');      //user password
        $group=$User->getValue($user, 'group');         //user's group ID
        $user_stat=$User->getValue($user, 'status');    //user status
        $group_stat=$Group->getValue($group, 'status'); //group status

        /*
            check user info
        */
        $errno='';
        $errno=(($user) ? 1 : 0).$errno;
        $errno=(($group) ? 1 : 0).$errno;
        $errno=((md5($pass)==$user_pass) ? 1 : 0).$errno;
//        $errno=(($user_stat=='active') ? 1 : 0).$errno;
//        $errno=(($group_stat=='active') ? 1 : 0).$errno;

        if($errno=='111')
        {
            if ($remember) {
                $uid = md5($login . md5($pass) . $_SERVER['HTTP_USER_AGENT']);
                setCookie('remember_user', $user, time() + $GLOBALS['CONF']['remember'], '/');
                setCookie('remember_uid', $uid, time() + $GLOBALS['CONF']['remember'], '/');
            } else {
                $_SESSION['ses_login']=$login;
                $_SESSION['ses_pass']=md5($pass);
                $_SESSION['ses_ip']=$_SERVER['REMOTE_ADDR'];
                $_SESSION['ses_browser']=$_SERVER['HTTP_USER_AGENT'];
            }
            return true;
        }
        else return false;
    }

/*
    logges user out the system
    receive nothing
    returnes true
*/
    function logout()
    {
        unset(
            $_SESSION['ses_login'],
            $_SESSION['ses_pass'],
            $_SESSION['ses_ip'],
            $_SESSION['ses_browser']);

        $this->login=null;
        $this->pass=null;
        $this->ip=null;
        $this->browser=null;

        setCookie('remember_user', null, 0);
        setCookie('remember_uid', null, 0);
        session_destroy();
        return true;
    }

/*
    checks whether user is authorized
    receives variable to put error number in
    returnes true is user is authorized, false otherwise
*/
    function is_authorized(&$errno)
    {
        $User = new TBL_User;
        $Group = new TBL_Group;
        $this->ICM_Access();
        if (isset($_COOKIE['remember_user']) && isset($_COOKIE['remember_uid'])) {
            $user = $_COOKIE['remember_user'];
        } else {
            $user = $User->id_by_login($this->login);         //user ID
        }
        /*
            get user info
        */
        $user_login=$User->getValue($user, 'login');    //user login
        $user_pass=$User->getValue($user, 'pass');      //user password
        $group=$User->getValue($user, 'group');         //user's group ID
        $user_stat=$User->getValue($user, 'status');    //user status
        $group_stat=$Group->getValue($group, 'status'); //group status

        if (isset($_COOKIE['remember_user']) && isset($_COOKIE['remember_uid'])) {
            $uid = md5($user_login . $user_pass . $_SERVER['HTTP_USER_AGENT']);
            if ($uid == $_COOKIE['remember_uid']) {
                $this->login = $user_login;
                $errno = 11111;
                return true;
            } else {
                $errno = 00000;
                return false;
            }
        } else {
            /*
                check user info
            */
            $errno='';
            $errno=(($user) ? 1 : 0).$errno;                                       //user exists
            $errno=(($group) ? 1 : 0).$errno;                                      //is assigned to a group
            $errno=(($user_pass==$this->pass) ? 1 : 0).$errno;                     //password provided matches
/*
            $errno=(($user_stat==ACTIVE) ? 1 : 0).$errno;                          //user is active
            $errno=(($group_stat==ACTIVE) ? 1 : 0).$errno;                         //group is active
*/
            $errno=(($_SERVER['REMOTE_ADDR']==$this->ip) ? 1 : 0).$errno;          //ip provided matches
            $errno=(($_SERVER['HTTP_USER_AGENT']==$this->browser) ? 1 : 0).$errno; //browser matches
    
            if ($errno == '11111') {
                return true;
            } else {
                return false;
            }
        }
    }

/*
    checks whether user is allowed to execute action over item with given attributes
    receives owner ID, item attributes, action name
    returnes true if user is allowed for the action, false otherwise
*/
    function is_allowed($owner, $attr, $action)
    {
        $User=new TBL_User;
        $Group=new TBL_Group;

        $attr=(string)$attr;
        $bits=array(
                    VIEW=>2,
                    EDIT=>1,
                    DELETE=>0);

        /*
            define user relation to item owner
        */
        if($this->login==ROOT) return true; //user is root, WOW!
        else
        {
            $user=$User->id_by_login($this->login);
            if($user==$owner) $attr_bin=decbin($attr{0}); //user is owner
            else
            {
                $user_grp=$User->getValue($user, 'group');
                $owner_grp=$User->getValue($owner, 'group');
                if($user_grp==$owner_grp) $attr_bin=decbin($attr{1}); //user is in owner's group
                else
                {
                    $owner_grp_parents=$Group->getParents($owner_grp);
                    if(in_array($user_grp, $owner_grp_parents))
                        $attr_bin=decbin($attr{1}); //user is in an owner group's parent
                    elseif($owner_grp==$Group->getValue($user_grp, 'parent'))
                        if($Group->getValue($user_grp, 'inheritance'))
                            $attr_bin=decbin($attr{1}); //user is an owner group's clild and can inherit
                        else $attr_bin=decbin($attr{2}); //user is just public for owner
                }
            }
            $attr_bin=str_pad($attr_bin, 3, '0', STR_PAD_LEFT);
            if($attr_bin{$bits[$action]}) return true;
            else return false;
        }
    }
}
?>