<?php
/*
    icmtml.class.php - contains ICM_TML class description
*/
$GLOBALS['TML'] = xparse_ini_file("{$GLOBALS['PTH']['conf']}icmtml.conf", true);  //ICM TML configs

/*
    class ICM_TML - class to work with templates based on ICM Template Markup Language
*/
class ICM_TML
{
    var $color;     //colors for ICM TML tags highlighting
    var $tags_dir;  //ICM TML tags interpreters' files location
    /* methods:
    bool ICM_TML()
    string parse(string tmpl_file)
    string showSource(string tmpl_file)
    */

/*
    constructor
    receives nothing
    returnes true
*/
    function ICM_TML()
    {
        $this->color = $GLOBALS['TML']['color'];
        $this->tags_dir = $GLOBALS['TML']['tags_dir'];
        $this->tags_ext = $GLOBALS['TML']['tags_ext'];
        $this->func_prefix = $GLOBALS['TML']['func_prefix'];
        return true;
    }

    
    function parseTemplate($tmpl_file)
    {
        $template = implode('', file($tmpl_file));
        return $this->parse($template);
    }
/*
    parses template file
    receives template file name
    returnes parsed template
*/
    function parse($template)
    {
        //match for tags wrapped by figure brackets
        preg_match_all("/{(.+)}/U", $template, $tags, PREG_SET_ORDER);

        //form pattern for retreiving tag name, parameters and their values
        $cn='\w\[\]';   //class of chars for tag/param name
        $c0="\s";       //    --||--         spaces
        $c1='^"';       //    --||--         double quoted value
        $c2="^'";       //    --||--         single quoted value
        $c3='^"\'\s';   //    --||--         not quoted value
        $pattern="/(\\/\\/.*)|(([$cn]+)[$c0]*(=[$c0]*((\"([$c1]+)\")|('([$c2]+)')|([$c3]+)))?)/";
        /*
            $1=  comment
            $2=  not comment :)
            $3=  tag name | param name
            $4=  =space "value" | ='value' | =value
            $5=  "value" | ='value' | =value
            $6=  "value" \ double quotes
            $7=  value   /
            $8=  'value' \ single quotes
            $9=  value   /
            $10= value   - no quotes
        */
        for ($i=0; $i<count($tags); $i++)
        {
            $tag=$tags[$i][1];
            // tagname param = value param = 'value' param = "value"
            preg_match_all($pattern, $tag, $params, PREG_SET_ORDER);
            $tag_params=array();
            for($j=0; $j<count($params); $j++)
            {
                if(isset($params[$j][1]) && strlen($params[$j][1])) $comment=$params[$j][1]; //comment
                elseif(!isset($tag_name)) $tag_name=$params[$j][3]; //tag name
                else
                {
                    //parameter
                    $parameter=$params[$j][3];
                    if(isset($params[$j][7]) && strlen($params[$j][7]))       $value=$params[$j][7];   //"value"
                    elseif(isset($params[$j][9]) && strlen($params[$j][9]))   $value=$params[$j][9];   //'value'
                    elseif(isset($params[$j][10]) && strlen($params[$j][10])) $value=$params[$j][10];  // value
                    else $value='';
                    $tag_params[$parameter]=$value;
                }
            }
            if(isset($tag_name))
            {
                if(!preg_match('/(\.\.)|(\/)/', $tag_name))
                {
                    $tml_file=$this->tags_dir.strtolower(trim($tag_name)).'.'.$this->tags_ext;
                    if(file_exists($tml_file))
                    {
                        include_once $tml_file;
                        $tml_func=$this->func_prefix.$tag_name;
                        $replace=$tml_func($tag_params);
                        $template=preg_replace('/'.preg_quote($tags[$i][0], '/').'/', $replace, $template);
                    }
                }
            }
            elseif(isset($comment)) $template=preg_replace('/'.preg_quote($tags[$i][0], '/').'/', '', $template);
            unset($tag_name, $params, $comment);
        }

        return $template;
    }

/*
    shows higlighted source of the template file
    receives template file name
    returnes highlighted source
*/
    function showSource($tmpl_file)
    {
        $template=implode('', file($tmpl_file));

        //match for tags wrapped by figure brackets
        preg_match_all("/{(.+)}/U", $template, $tags, PREG_SET_ORDER);

        //form pattern for retreiving tag name, parametrs and their values
            $cn='\w\[\]';   //class of chars for tag/param name
            $cb="\W";       //    --||--         space before tag/param name
            $c0="\s";       //    --||--         spaces
            $c1='^"';       //    --||--         double quoted value
            $c2="^'";       //    --||--         single quoted value
            $c3='^"\'\s';   //    --||--         not quoted value
            $pattern="/([$c0]*)((\\/\\/)(.+))|(([$c0]*)([$cn]+)([$c0]*)(=([$c0]*)((\"([$c1]+)\")|('([$c2]+)')|([$c3]+)))?)([$c0]*)/";
            /*
                $1=  space
                $2=  comment group
                $3=  // - comment sign
                $4=  comment
                $5=  not-comment group
                $6=  space
                $7=  tag name | param name
                $8=  space
                $9=  =space "value" | ='value' | =value
                $10=  space
                $11=  "value" | ='value' | =value
                $12= "value" \ double quotes
                $13= value   /
                $14= 'value' \ single quotes
                $15= value   /
                $16= value   - no qiotes
                $17= space
            */
        $template=htmlspecialchars($template);
        for ($i=0; $i<count($tags); $i++)
        {
            $source="<font color={$this->color['parantheses']}>{</font>";
            $tag=$tags[$i][1];
            // tagname param = value param = 'value' param = "value"
            preg_match_all($pattern, $tag, $params, PREG_SET_ORDER);
            for($j=0; $j<count($params); $j++)
            {
                $source.=$params[$j][1];    //space

                if(isset($params[$j][2]) && strlen($params[$j][2]))
                {
                    //comment
                    $comment=$params[$j][4];
                    $source.="<font color={$this->color['comment']}>//$comment</font>";
                }
                elseif(!isset($tag_name))
                {
                    //tag name
                    $space=$params[$j][6];
                    $tag_name=$params[$j][7];
                    $source.="$space<font color={$this->color['tagname']}>$tag_name</font>";
                    $source.=$params[$j][8];
                }
                else
                {
                    //parameter
                    $parameter=$params[$j][7];
                    $source.="<font color={$this->color['parameter']}>$parameter</font>";
                    $source.=$params[$j][8];
                    if(isset($params[$j][13]) && strlen($params[$j][13]))
                    {
                        //double quoted value
                        $space=$params[$j][10];
                        $value=$params[$j][13];
                        $source.="=$space<font color={$this->color['quote']}>\"</font><font color={$this->color['value']}>$value</font><font color={$this->color['quote']}>\"</font>";
                    }
                    elseif(isset($params[$j][15]) && strlen($params[$j][15]))
                    {
                        //single quoted value
                        $space=$params[$j][10];
                        $value=$params[$j][15];
                        $source.="=$space<font color={$this->color['quote']}>'</font><font color={$this->color['value']}>$value</font><font color={$this->color['quote']}>'</font>";
                    }
                    elseif(isset($params[$j][16]) && strlen($params[$j][16]))
                    {
                        //not quoted value
                        $space=$params[$j][8];
                        $value=$params[$j][16];
                        $source.="=$space<font color={$this->color['value']}>$value</font>";
                    }
                    $source.=$params[$j][17];   //space
                }
            }
            $source.="<font color={$this->color['parantheses']}>}</font>";
            $template=preg_replace('/'.preg_quote(htmlspecialchars($tags[$i][0]), '/').'/', $source, $template);
            unset($tag_name, $params);
        }
        $template=preg_replace("/[\040]{2}/", "&nbsp;&nbsp;", $template);
        
        $lines = explode("\n", $template);
        for ($i = 0; $i < count($lines); $i ++) {
            $lines[$i] =  str_pad($i + 1, 3, '0', STR_PAD_LEFT) . ':' . $lines[$i];
        }
        $template = implode('<br />', $lines);

        return "<font face=Courier size=2 color=#000000>$template</font>";
    }
}
?>