<?php
/*
    section.class.php - contains TBL_Section class description
*/

require_once "table.class.php";	//ICM_Table description
require_once "user.class.php";	//TBL_User description

/*
    class TBL_Section - class to work with Sections module database table
*/
class TBL_Section extends ICM_Table
{
    /* methods:
    bool TBL_Content()
    int insert(array data)
    bool update(int id, array data)
    int IdByNameNParent(string name, int parent)
    int IDByPath(array path)
    array getChildren(int id)
    array getParents(int id)
    string getPath(int id)
    int getLevel(int id)
    */

/*
    constructor, mainly calles ICM_Table constructor
    receives nothing
    returnes true if succeed
*/
    function TBL_Section()
    {
        $called=ICM_Table::ICM_Table($GLOBALS['TBL']['sections'], '_trans', 'section', 'language');
        
        if (isset($_SESSION['all_sections'])) {
            $GLOBALS['all_sections'] = $_SESSION['all_sections'];
        }
        if (!isset($GLOBALS['all_sections'])) {
            $GLOBALS['all_sections'] = $this->selectAll();
        }
        if (!isset($_SESSION['all_sections'])) {
            $_SESSION['all_sections'] = $GLOBALS['all_sections'];
        }
        
        foreach ($GLOBALS['all_sections'] as $section) {
            $GLOBALS['all_sections_by_id'][$section['id']] = $section;
        }
        
        return $called;
    }

/*
    extends insert() method in ICM_Table class
    receives data to insert
    returnes inserted ID
*/
    function insert($data)
    {
        $User = new TBL_User;
        $Lang = new TBL_Lang;
        
        if (!isset($data['name']) || !strlen($data['name'])) {
            if (isset($data['title'][$def_lang]) && strlen($data['title'][$def_lang])) {
                $def_lang = $Lang->id_by_name($GLOBALS['CONF']['admin_def_lang']);
                $data['name'] = translit($data['title'][$def_lang]);
            } else {
                $data['name'] = 'default';
            }
        }
        
        $data['created'] = date('Y-m-d H:i:s', time());
        $data['modified'] = date('Y-m-d H:i:s', time());
        $data['owner'] = (empty($data['owner'])) ? $User->id_by_login($_SESSION['ses_login']) : null;
        $added = ICM_Table::insert($data);
        unset($_SESSION['all_sections']);
        return $added;
    }

/*
    extends update() method in ICM_Table class
    receives row ID and data to update
    returnes true if succeed
*/
    function update($id, $data)
    {
        $Lang = new TBL_Lang;
        
        if (isset($data['name']) && !strlen($data['name'])) {
            $def_lang = $Lang->id_by_name($GLOBALS['CONF']['admin_def_lang']);
            $title = (isset($data['title'][$def_lang]) && strlen($data['title'][$def_lang]))
                   ? $data['title'][$def_lang]
                   : $this->getTValue($id, $def_lang, 'title');
            if (strlen($title)) {
                $data['name'] = translit($data['title'][$def_lang]);
            } else {
                $data['name'] = 'default';
            }
        }

        $data['modified'] = date('Y-m-d H:i:s', time());
        $updated = ICM_Table::update($id, $data);
        unset($_SESSION['all_sections']);
        return $updated;
    }

    function delete($id)
    {
        $deleted = parent::delete($id);
        unset($_SESSION['all_sections']);
        return $deleted;
    }

    function select($id)
    {
        if (isset($GLOBALS['all_sections_by_id'][$id])) {
            return $GLOBALS['all_sections_by_id'][$id];
        } else {
            parent::select($id);
        }
    }

    function getChildren($id)
    {
        $all_sections = $GLOBALS['all_sections'];
        $children = array();
        $parent = ($id!=null)?$id:0;
        foreach($all_sections as $sec) {
            if($sec['parent'] == $parent)
    	    array_push($children, $sec['id']);
        }
        return $children;
    }
    
    
    function getValue($id, $field)
    {
        $all_sections = $GLOBALS['all_sections'];
        $value = false;
        foreach($all_sections as $sec) {
            if($sec['id'] == $id)
                $value = (isset($sec[$field]))?$sec[$field]:null;
        }
        return $value;
    }
    
    function IdByNameNParent($name, $parent)
    {
        $all_sections = $GLOBALS['all_sections'];
        $id = false;
        foreach($all_sections as $sec) {
            if($sec['name'] == $name && $sec['parent'] == $parent)
                $id = $sec['id'];
        }
        return $id;
    }
    
    function getParents($id)
    {
        $all_sections = $GLOBALS['all_sections'];
        $parents = array();
        $parent = $this->getValue($id, 'parent');
        while($parent)
        {
            array_push($parents, $parent);
            $parent = $this->getValue($parent, 'parent');
        }
        return $parents;
    }
    
    function getPath($id)
    {
        $all_sections = $GLOBALS['all_sections'];
        $parents = $this->getParents($id);
        if (count($parents)) {
            $home = array_pop($parents);
            array_unshift($parents, $id);
        }
        $path = '';
        foreach($parents as $parent) {
            $path = $this->getValue($parent, 'name') . '/' . $path;
        }
        return $path;
    }
    
    function getTValue($id, $lang, $field)
    {
        $all_sections = $GLOBALS['all_sections'];
        $value = false;
        foreach($all_sections as $sec) {
            if($sec['id'] == $id)
                $value = (isset($sec[$field][$lang]))?$sec[$field][$lang]:null;
        }
        return $value;
    }
    
    function IdByPath($path)
    {
        $all_sections = $GLOBALS['all_sections'];
        $parent=0;
        foreach($path as $key => $name)
        {
            $id = $this->IdByNameNParent($name, $parent);
            if($id) $parent=$id;
            else break;
        }
        return $parent;
    }
/*
    gets parents number
    receives section ID
    returnes integer
*/
    function getLevel($id)
    {
        $parents=$this->getParents($id);
        $level=count($parents);
        return $level;
    }
}
?>