<?php
/*
    table.class.php - contains ICM_Table class description
*/

$GLOBALS['TBL']=xparse_ini_file("{$GLOBALS['PTH']['conf']}tables.conf", true);  //tables' configs
require_once "db.class.php";    //ICM_DB description

/*
    class ICM_Table - class to work with database tables
*/
class ICM_Table
{
    var $db;       //database object
    var $_name;    //table name
    var $_trans;   //postfix for tables with translatable data
    var $_item;    //key-item field name
    var $_lang;    //language field name
    
    var $_cache;
    /* methods:
    bool ICM_Table(array table_attrib)
    int insert(array data)
    bool update(int id, array data)
    bool delete(int id)
    array select(int id)
    array all([...])
    array selectAll([...])
    mixed getValue(int id, string field);
    mixed getTValue(int id, int lang, string field);
    */

/*
    constructor
    receives table attributes
    returnes true
*/
    function ICM_Table($table_name, $trans_postfix, $keyitem, $langfield)
    {
        $this->db = $GLOBALS['DB_CLASS_INSTANCE'];
        $this->_name=$table_name;
        $this->_trans=$trans_postfix;
        $this->_item=$keyitem;
        $this->_lang=$langfield;
        $this->_cache = array();
        return true;
    }

/*
    inserts data in table
    receives data to insert
    returnes inserted ID
*/
    function insert($data)
    {

        /*
            first parse data, get fields and values
            if $data[$field] is an array it means that it's translatable data
            where $data[$field][$lang] - is it's value and $lang - language ID
        */
        foreach($data as $field => $value)
            if(!is_array($value))
            {
                if(isset($fields)) $fields.=", `$field`";
                else $fields="`$field`";
                if(isset($values)) $values.=" ,'$value'";
                else $values="'$value'";
            }
            else
                foreach($value as $lang => $value_trans)
                {
                    if(isset($fields_trans[$lang])) $fields_trans[$lang].=", `$field`";
                    else $fields_trans[$lang]="`$field`";
                    if(isset($values_trans[$lang])) $values_trans[$lang].=", '$value_trans'";
                    else $values_trans[$lang]="'$value_trans'";
                }

        /*
            insert data
        */
        $query="insert into `{$this->_name}` ($fields) values ($values)";
        $result=$this->db->exeQuery($query);
        $last_id=$this->db->lastID();

        /*
            if there is translatable data then insert it
        */
        if(isset($fields_trans))
            foreach($fields_trans as $lang => $fields)
            {
                $values=$values_trans[$lang];
                $query="insert into `{$this->_name}{$this->_trans}` (`{$this->_item}`, `{$this->_lang}` ,$fields)
                        values ('$last_id', '$lang', $values)";
                $result=$this->db->exeQuery($query);
            }

        return $last_id;
    }

/*
    updates data in table
    receives ID of a row, data to update
    returnes true if succeed
*/
    function update($id, $data)
    {

        /*
            first check if there is row with such ID
            if not we insert data instead of updating it
        */
        $query="select count(*) from `{$this->_name}` where `id`='$id'";
        $num=$this->db->getResult($query);
        if($num)
        {
            /*
                like in insert(), we parse data first
            */
            foreach($data as $field => $value)
                if(!is_array($value))
                    if(isset($sets)) $sets.=", `$field`='$value'";
                    else $sets="`$field`='$value'";
                else
                    foreach($value as $lang => $value_trans)
                    {
                        $query="select count(*) from `{$this->_name}{$this->_trans}`
                                where `{$this->_item}`='$id' and `{$this->_lang}`='$lang'";
                        $num=$this->db->getResult($query);
                        if($num)
                            if(isset($sets_trans[$lang])) $sets_trans[$lang].=", `$field`='$value_trans'";
                            else $sets_trans[$lang]="`$field`='$value_trans'";
                        else
                            $query="insert into `{$this->_name}{$this->_trans}`
                                    (`{$this->_item}`, `{$this->_lang}`, $field)
                                    values ('$id', '$lang', '$value_trans')";
                            $this->db->exeQuery($query);
                    }

            /*
                update data
            */
            $query="update `{$this->_name}` set $sets where `id`='$id'";
            $result=$this->db->exeQuery($query);

            /*
                update translatable data
            */
            if(isset($sets_trans))
                foreach($sets_trans as $lang => $set)
                {
                    $query="update `{$this->_name}{$this->_trans}`
                            set $set
                            where `{$this->_item}`='$id' and `{$this->_lang}`='$lang'";
                    $result=$this->db->exeQuery($query);
                }
        }
        else
        {
            $data['id']=$id;
            $result=$this->insert($data);
        }
        
        unset($this->_cache[$id]);
        
        return (bool)$result;
    }

/*
    deletes data from table
    receives ID of a row to delete
    returnes true if succeed
*/
    function delete($id)
    {

        /*
            delete data
        */
        $query="delete from `{$this->_name}` where `id`='$id'";
        $result=$this->db->exeQuery($query);

        /*
            delete translatable data if exists
        */
        if(in_array($this->_name.$this->_trans, $this->db->getTables()))
        {
            $query="delete from `{$this->_name}{$this->_trans}` where `{$this->_item}`='$id'";
            $result=$this->db->exeQuery($query);
        }

        unset($this->_cache[$id]);
        
        return (bool)$result;
    }

/*
    gets row with given ID
    receives row ID
    returnes associative array of data or empty array if row does not exists
*/
    function select($id)
    {
        if (isset($this->_cache[$id])) {
            $data = $this->_cache[$id];
        } else {
            $data = array();
            /*
                get data
            */
        	$is_trans = in_array($this->_name.$this->_trans, $this->db->getTables());
        	if ($is_trans) {
                $query = "select t.*, m.* from {$this->_name} m"
                       . " left join {$this->_name}{$this->_trans} t on (t.{$this->_item} = m.id)"
                       . " where m.id = '$id' group by {$this->_lang}";
        	} else {
                $query = "select * from {$this->_name} where id = '$id'";
        	}
            $result = $this->db->exeQuery($query);

            $main_fields = $this->db->getFields($this->_name);
            if ($is_trans) {
                $trans_fields = $this->db->getFields($this->_name . $this->_trans);
                $trans_fields = array_flip($trans_fields);
            } else {
                $trans_fields = array();
            }
            unset($trans_fields[$this->_item], $trans_fields[$this->_lang]);
            $trans_fields = array_flip($trans_fields);
    
            $data = array();
            while ($row = mysql_fetch_assoc($result)) {
                foreach ($row as $field => $value) {
                    if (in_array($field, $main_fields)) {
                        $data[$field] = $value;
                    } elseif (in_array($field, $trans_fields)) {
                        $data[$field][$row[$this->_lang]] = $value;
                    }
                }
            }
            if (isset($data['id'])) {
                $this->_cache[$data['id']] = $data;
            }
        }
        return $data;
    }

/*
    gets all data from table
    receives:
        nothing
        or: where
        or: start, limit
        or: order, [dir]
        or: start, limit, order, [dir], [where]
    returnes array of IDs
*/
    function all()
    {

        /*
            get arguments and parse them
        */
        $args=func_get_args();
        $args_num=count($args);

        if($args_num==1)
        {
            if(is_string($args[0])) $where=$args[0];
            elseif(is_numeric($args[0])) $limit=$args[0];
        }
        elseif($args_num==2)
        {
            if(is_numeric($args[0]) && is_numeric($args[1]))
            {
                $start=$args[0];
                $limit=$args[1];
            }
            elseif(is_string($args[0]) && is_string($args[1]))
            {
                $order=$args[0];
                $dir=$args[1];
            }
        }
        elseif($args_num>=3)
        {
            if(is_numeric($args[0])) $start=$args[0];
            if(is_numeric($args[1])) $limit=$args[1];
            if(is_string($args[2])) $order=$args[2];
            if(isset($args[3])) if(is_string($args[3])) $dir=$args[3];
            if(isset($args[4])) if(is_string($args[4])) $where=$args[4];
        }

        $row=array();
        $order4query='';
        $limit4query='';
        $where4query='';

        if(isset($order))
        {
            if(in_array($this->_name.$this->_trans, $this->db->getTables()))
                $all_fields=array_merge($this->db->getFields($this->_name), $this->db->getFields($this->_name.$this->_trans));
            else
                $all_fields=$this->db->getFields($this->_name);
            if(in_array($order, $all_fields))
            {
                $order4query="order by `$order`";
                if(isset($dir))
                    if(in_array($dir, array('desc', 'asc'))) $order4query.=" $dir";
            }
        }
        if(isset($limit))
        {
            if ($start < 0) {
                $start = 0;
            }
            if(isset($start)) $limit4query="limit $start, $limit";
            else $limit4query="limit $limit";
        }
        if(isset($where)) $where4query=" $where";

        if(in_array($this->_name.$this->_trans, $this->db->getTables()))
            $query="select tbl.id from `{$this->_name}` as tbl, `{$this->_name}{$this->_trans}` as tbl_t
                    where tbl.id=tbl_t.{$this->_item} $where4query $order4query $limit4query";
        else
            $query="select id from `{$this->_name}`
                    where 1 $where4query $order4query $limit4query";

        $result=$this->db->exeQuery($query);
        while($data=mysql_fetch_assoc($result))
            if(!in_array($data['id'], $row)) array_push($row, $data['id']);

        return $row;
    }

/*
    selects all data from table
    gets all data from table
    receives:
        nothing
        or: where
        or: start, limit
        or: order, [dir]
        or: start, limit, order, [dir], [where]
    returnes associative array of data
*/
    function selectAllOld()
    {
        $data=array();
        $args=func_get_args();
        $rows=call_user_func_array(array(&$this, 'all'), $args);
        foreach($rows as $id)
            array_push($data, $this->select($id));
        return $data;
    }

    function selectAll()   // by oSS
    {

	$isTrans = in_array($this->_name.$this->_trans, $this->db->getTables());
	$args=func_get_args();
	$args_num=count($args);

	if($args_num==1)
        {
            if(is_string($args[0])) $where=$args[0];
            elseif(is_numeric($args[0])) $limit=$args[0];
        }
        elseif($args_num==2)
        {
            if(is_numeric($args[0]) && is_numeric($args[1]))
            {
                $start=$args[0];
                $limit=$args[1];
            }
            elseif(is_string($args[0]) && is_string($args[1]))
            {
                $order=$args[0];
                $dir=$args[1];
            }
        }
        elseif($args_num>=3)
        {
            if(is_numeric($args[0])) $start=$args[0];
            if(is_numeric($args[1])) $limit=$args[1];
            if(is_string($args[2])) $order=$args[2];
            if(isset($args[3])) if(is_string($args[3])) $dir=$args[3];
            if(isset($args[4])) if(is_string($args[4])) $where=$args[4];
        }

        $order4query = '';
        $limit4query = '';
        $where4query = '';

        
        if (isset($order)) {
            if ($isTrans) {
                $all_fields = array_merge($this->db->getFields($this->_name), $this->db->getFields($this->_name.$this->_trans));
            } else {
                $all_fields = $this->db->getFields($this->_name);
            }
            if (in_array($order, $all_fields)) {
                $order4query .= " order by `$order`";
                if (isset($dir)) {
                    if (in_array($dir, array('desc', 'asc'))) {
                        $order4query .= " $dir";
                    }
                }
            }
        }

        if(isset($limit))
        {
            if (isset($start)) {
                $limit4query = " limit $start, $limit";
            }  else {
                $limit4query = " limit $limit";
            }
        }
        if (isset($where)) {
            $where4query = ' ' . preg_replace("/and .?language.?='.'/", "", $where);
        }

        $main_fields = $this->db->getFields($this->_name);
        if ($isTrans) {
            $trans_fields = $this->db->getFields($this->_name . $this->_trans);
            $trans_fields = array_flip($trans_fields);
        } else {
            $trans_fields = array();
        }
        unset($trans_fields[$this->_item], $trans_fields[$this->_lang]);
        $trans_fields = array_flip($trans_fields);

        if ($isTrans) {
            if (isset($GLOBALS['ENV']['sys_lang_id'])) {
                $cur_lang = "t.{$this->_lang} = {$GLOBALS['sys_lang_id']}";
            } else {
                $cur_lang = '1';
            }
            $query = "select id from {$this->_name} m"
                   . " left join {$this->_name}{$this->_trans} t on (`{$this->_item}` = id)"
                   . " where {$cur_lang} {$where4query} group by m.id {$order4query}{$limit4query}";
            $result = $this->db->exeQuery($query);
            $ids = array(0);
            while ($row = mysql_fetch_assoc($result)) {
                $ids[] = $row['id'];
            }
            $id_set = implode(',', $ids);
            
            if (isset($limit)) {
                if (isset($GLOBALS['all_langs'])) {
                    $limit *= count($GLOBALS['all_langs']);
                    if (isset($start)) {
                        $start *= count($GLOBALS['all_langs']);
                    }
                    if (isset($start)) {
                        $limit4query = " limit $start, $limit";
                    } else {
                        $limit4query = " limit $limit";
                    }
                }
            }
            $query = "select t.*, m.* from {$this->_name} m"
                   . " left join {$this->_name}{$this->_trans} t on (t.{$this->_item} = m.id)"
                   . " where m.id in ($id_set) group by m.id, {$this->_lang}";
        } else {
            $query = "select * from {$this->_name}"
                   . " where 1 {$where4query}{$order4query}{$limit4query}";
        }
        $result = $this->db->exeQuery($query);
        $data = array();
        while ($row = mysql_fetch_assoc($result)) {
            foreach ($row as $field => $value) {
                if (in_array($field, $main_fields)) {
                    $data[$row['id']][$field] = $value;
                } elseif (in_array($field, $trans_fields)) {
                    $data[$row['id']][$field][$row[$this->_lang]] = $value;
                }
            }
        }

	    $i = 0;
	    $data_by_flow = array();
	    if (isset($ids) && count($ids)) {
    	    foreach ($ids as $id) {
    	        if (isset($data[$id])) {
        	        $data_by_flow[$i] = $data[$id];
        	        $this->_cache[$id] = $row;
        	        $i ++;
    	        }
    	    }
            return $data_by_flow;
	    } else {
	        foreach ($data as $row) {
    	        $this->_cache[$row['id']] = $row;
	        }
	        return $data;
	    }

    }
    
    /*
    gets field value of row with given ID, if such exists
    receives row ID and field name
    returnes field value or false if row doesn't exists
*/
    function getValue($id, $field)
    {
        $value = false;
        $data = $this->select($id);
        if (isset($data[$field])) {
            $value = $data[$field];
        } else {
            $value = null;
        }
        return $value;
    }

/*
    gets value of translatable field
    receives row ID, language ID, field name
    returnes field value or false if does not exists
*/
    function getTValue($id, $lang, $field)
    {
        $data = $this->select($id);
        if (isset($data[$field][$lang])) {
            $value = $data[$field][$lang];
        } else {
            $value = null;
        }
        return $value;
    }

}
?>