<?php
//form.func.php - form elements
require_once "{$GLOBALS['PTH']['classes']}lang.class.php";
require_once "common.func.php";

//string form_input(string type, string name, mixed value, [string css_class, array js_events, bool readonly])
//string form_button(string type, string name, string title, [string css_class, array js_events, string image]);

function form_input($type, $name, $value, $css_class=null, $js_events=array(), $readonly=false, $title=null, $opt_titles=array(), $opt_values=array(), $size = 1)
{
    //makes input element
    //receives elements attributes
    //returnes string - HTML code

    //prepare JavaScript events
    global $sys_lang_id;
    
    $str_js_events='';
    if(is_array($js_events))
    {
        if(!is_array(reset($js_events)) && reset($js_events)) $js_events=array($js_events);
        foreach($js_events as $event)
            $str_js_events.=" {$event['name']}=\"{$event['value']}\"";
    }

    //prepare readonly attribute
    $str_readonly=($readonly) ? ' readonly' : '';

    //CSS class
    $str_css_class=(isset($css_class)) ? " class=\"$css_class\"" : '';

    switch($type)
    {
        case 'text':
        case 'password':
        case 'hidden':
            if($type=='password') $value='';
            $str_input=
<<<HTML
<input type="$type" name="$name" value="$value"{$str_css_class}{$str_js_events}{$str_readonly} />
HTML;
            break;
        case 'textarea':
            $str_input=
<<<HTML
<textarea name="$name"{$str_css_class}{$str_js_events}{$str_readonly}>$value</textarea>
HTML;
            break;
        case 'file': case 'image':
        	if(is_array($value) && isset($value['name'])) $value = $value['name'];
            $str_input=
<<<HTML
<input type="file" name="$name"{$str_css_class}{$str_js_events}{$str_readonly} />
<br><input type="hidden" name="{$name}_value" value="{$value}" />{$value}
HTML;
            break;
        case 'label':
            $str_input=
<<<HTML
<span id="$name"{$str_css_class}{$str_js_events}>$value</span>
HTML;
            break;
        case 'checkbox':
            $str_checked=($value) ? ' checked' : '';
            $str_input=
<<<HTML
<div style="padding: 0px; margin: 0px;">
<input type="$type" name="$name"{$str_checked}{$str_css_class}{$str_js_events}{$str_readonly}>
<span style="cursor: default;"
 onClick="if (this.parentNode.childNodes[0].tagName=='INPUT') {e=this.parentNode.childNodes[0]} else {e=this.parentNode.childNodes[1]}
 if (e.checked) {e.checked=false} else {e.checked=true}">
$title
</span>
</div>
HTML;
            break;
        case 'pick':
            $btn_pick = form_button('image', 'pick_' . $name, '...', 'input-image', $js_events, null, $GLOBALS['URL']['buttons'] . 'pick.gif');
            $btn_clear = form_button('image', 'clear_' . $name, '...', 'input-image', array(array('name' => 'onClick', 'value' => "clearPick('$name')")), null, $GLOBALS['URL']['buttons'] . 'clear.gif');
            $str_input=
<<<HTML
<input type="text" name="{$name}_title"{$str_css_class} readonly value="$title" />
<input type="hidden" name="$name" value="$value" />
$btn_pick
$btn_clear
HTML;
            break;
        case 'xtextarea':
            $btn_pop = form_button('image', 'pop_' . $name, '...', 'input-image', array(array('name' => 'onClick', 'value' => "popXTextArea('$name')")), null, $GLOBALS['URL']['buttons'] . 'wysiwyg.gif');
            $btn_toggle = form_button('image', 'toggle_' . $name, '...', 'input-image" style="float: right;', array(array('name' => 'onClick', 'value' => "toggleXTextArea(this, '$name')")), null, $GLOBALS['URL']['buttons'] . 'minimize.gif');
            $str_input =
<<<HTML
<div>
    <div>
        $btn_pop
        <a href="javascript://toggle/this" onClick="popXTextArea('$name');return false;">{$GLOBALS['LANG']['button']['wysiwyg']}</a>
        $btn_toggle
    </div>
    <textarea name="$name"{$str_css_class}{$str_js_events}{$str_readonly}>$value</textarea>
</div>
HTML;
            break;
        case 'select':
            $str_input=
<<<HTML
<select name="{$name}"{$str_css_class}{$str_js_events} size="$size">
HTML;
            foreach($opt_values as $key => $opt_value)
            {
                $selected=($opt_value==$value) ? ' selected' : '';
                $str_input.=
<<<HTML
<option value="$opt_value"{$selected}>{$opt_titles[$key]}</option>
HTML;
            }
            $str_input.=
<<<HTML
</select>
HTML;
            break;
        case 'selectbox':
            $str_input =
<<<HTML
<select name="{$name}"{$str_css_class} multiple="yes" size="$size">
HTML;
            foreach($opt_values as $key => $opt_value) {
                $selected = (in_array($opt_value, $value)) ? ' selected' : '';
                if (isset($opt_classes[$key]) && strlen($opt_classes[$key])) {
                    $str_class = ' class="' . $opt_classes[$key] . '"';
                } else {
                    $str_class = '';
                }
                $str_input .=
<<<HTML
<option value="$opt_value"{$selected}{$str_class}>{$opt_titles[$key]}</option>
HTML;
            }
            $str_input.=
<<<HTML
</select>
HTML;
            break;
        case 'radio':
            $str_input=
<<<HTML
<ul style="list-style: none; padding: 0px; margin: 0px;">
HTML;
            foreach($opt_values as $key => $opt_value)
            {
                $checked=($opt_value==$value) ? ' checked' : '';
                $str_input.=
<<<HTML
<li style="padding: 0px; margin: 0px;">
<input type="radio" name="{$name}" value="$opt_value"$checked>
<span style="cursor: default;"
 onClick="if (this.parentNode.childNodes[0].tagName=='INPUT') {e=this.parentNode.childNodes[0]} else {e=this.parentNode.childNodes[1]} e.checked=true;">
  {$opt_titles[$key]}
</span>
</li>
HTML;
            }
            $str_input.=
<<<HTML
</ul>
HTML;
            break;
        case 'answers':
            $str_input =
<<<HTML
<div style="border: 1px solid #ccc; background: #fff; padding: 3px; margin: 3px; width: 500px; height: 200px; overflow: auto;">
<input id="btn_answer" type="button" class="input-button" onClick="addPollAnswer(this)" value="[+]">
</div>
HTML;

            $str_input .=
<<<HTML
<script language="JavaScript" type="text/javascript">
btn = document.getElementById('btn_answer');
HTML;
			if (is_array($value)) {
	            foreach ($value as $answer) {
	                $str_ans = 'var ans = new Array();';
	                foreach ($answer['answer'] as $lang => $ans) {
	                    $str_ans .= "ans[$lang] = '$ans';\n";
	                }
	                $str_input .= js_addPollAnswer();
	                $str_input .=
<<<HTML
$str_ans
addPollAnswer(btn, {$answer['id']}, ans, {$answer['votes']});
HTML;
	            }
            }
            $str_input .=
<<<HTML
</script>
HTML;
            break;
        case 'menuitems':
            $Section = new TBL_Section;
            $str_input =
<<<HTML
<div style="border: 1px solid #ccc; background: #fff; padding: 3px; margin: 3px; width: 500px; height: 200px; overflow: auto;">
<input id="btn_item" type="button" class="input-button" onClick="addMenuItem(this)" value="[+]">
</div>
HTML;

            $str_input .=
<<<HTML
<script language="JavaScript" type="text/javascript">
btn = document.getElementById('btn_item');
HTML;
            $str_input .= js_addMenuItem();

            $n = 0;
			if (is_array($value)) {
	            foreach ($value as $n => $item) {
	                $section_title = $Section->getTValue($item['section'], $sys_lang_id, 'title');
	                $str_input .=
<<<HTML
addMenuItem(btn, {$item['id']}, '$section_title', {$item['section']}, $n);
HTML;
	            }
            }
            $str_input .=
<<<HTML
var last_order = $n;
</script>
HTML;
            break;
    }


    return $str_input;
}

function form_button($type, $name, $title, $css_class=null, $js_events=array(), $value=null, $image=null)
{
    //makes button
    //receives button attributes
    //returnes string - button HTML code

    //prepare JavaScript events
    $str_js_events='';
    if(is_array($js_events))
        foreach($js_events as $event)
            $str_js_events.=" {$event['name']}=\"{$event['value']}\"";

    //CSS class
    $str_css_class=(isset($css_class)) ? " class=\"$css_class\"" : '';

    switch($type)
    {
        case 'button':
        case 'submit':
        case 'reset':
        case 'hidden':
            $str_button="<input type=\"$type\" name=\"$name\" value=\"$title\"{$str_css_class}{$str_js_events} />";
            if(isset($value)) $str_button.="<input type=\"hidden\" name=\"{$name}_value\" value=\"$value\" />";
            break;
        case 'image':
            $str_button="<img src=\"$image\" name=\"$name\" alt=\"$title\" title=\"$title\"{$str_css_class}{$str_js_events} />";
            if(isset($value)) $str_button.="<input type=\"hidden\" name=\"{$name}_value\" value=\"$value\" />";
            break;
    }
    return $str_button;
}
?>