<?php
/*
    general.func.php - contains general module functions
*/

require_once "{$GLOBALS['PTH']['classes']}lang.class.php";  //TBL_Lang description
require_once "common.func.php"; //common functions
require_once "form.func.php";   //form functions

/*
    void makeForm(array data, array data_struct, array buttons, int lang)
    void makeList(array data, array data_struct, array buttons, int lang)
    void makeView(array data, array data_struct, array buttons, int lang)
    string block_filter(string params)
    string block_pages(string params)
    string block_perpage(string params)
    string block_search(string params)
*/

/*
    makes and outputs form for adding, editing and copying items
    receives data, data structure, buttons structure, language ID
    returnes true
*/
function makeForm($data, $data_struct, $buttons, $lang)
{

    global $sys_lang_id;
    $langs = array();
    foreach ($GLOBALS['all_langs'] as $lang) {
        $langs[$lang['id']] = $lang['title'][$sys_lang_id];
    }
    
    $records_by_type = array();
    $records_by_name = array();
    foreach ($data_struct as $record) {
        $records_by_type[$record['type']][] = $record;
        $records_by_name[$record['name_dbase']] = $record;
    }
    
    $HTML =
<<<HTML
<dl class="form-builder-tabs">
HTML;
    
    foreach ($records_by_type as $type => $records) {
        $tab_title = isset($GLOBALS['LANG']['label'][$type]) ? $GLOBALS['LANG']['label'][$type] : $type;
        $HTML .=
<<<HTML
    <dt class="form-builder-tab">{$tab_title}</dt>
HTML;
    }
    
    foreach ($records_by_type as $type => $records) {
        $HTML .=
<<<HTML
    <dd class="form-builder-tab">
HTML;
        if ($type == 'attributes') {
            
    //get attributes values
    $attr = array(
        'owner'  => array('view', 'edit', 'delete'),
        'group'  => array('view', 'edit', 'delete'),
        'public' => array('view', 'edit', 'delete'),
    );
    
    $i = 0;
    foreach ($attr as $key => $user) {
        $attr_bin = decbin($data['attributes']{$i});
        $attr_bin = str_pad($attr_bin, 3, "0", STR_PAD_LEFT);
        $j = 0;
        foreach ($user as $action) {
            $checked[$key][$action] = ($attr_bin{2 - $j}) ? ' checked' : '';
            $j ++;
        }
        $i ++;
    }

    $HTML .=
<<<HTML
        <table width="100%">
          <tr>
            <td>
              <table class="attributes">
                <tr class="tr-content">
                  <td class="td-content"></td>
                  <td class="td-title">{$GLOBALS['LANG']['attr']['view']}</td>
                  <td class="td-title">{$GLOBALS['LANG']['attr']['edit']}</td>
                  <td class="td-title">{$GLOBALS['LANG']['attr']['delete']}</td>
                  <td class="td-content" width=100%></td>
                </tr>
HTML;
    foreach ($attr as $key => $user) {
        $HTML .=
<<<HTML
        <tr class="tr-content">
          <td class="td-title">{$GLOBALS['LANG']['attr'][$key]}:</td>
HTML;
        foreach ($user as $action) {
            $HTML .=
<<<HTML
          <td class="td-content">
            <input type=checkbox name=attr_{$key}_{$action}{$checked[$key][$action]} />
          </td>
HTML;
        }
        $HTML .=
<<<HTML
          <td class="td-content" width="100%"></td>
        </tr>
HTML;
    }
    $HTML .=
<<<HTML
              </table>
            </td>
          </tr>
        </table>
HTML;
        } else {
        foreach ($records as $record) {
            
            //prepare title if needed, e.g. for picks
            if (isset($record['list_func'])) {
                $params = array();
                if (!is_array($record['list_func']['params'])) {
                    $record['list_func']['params'] = array($record['list_func']['params']);
                }
                foreach($record['list_func']['params'] as $var_name) {
                    if (isset($data[$var_name])) {
                        if (is_array($data[$var_name])) {
                            array_push($params, $data[$var_name][$sys_lang_id]);
                        } else {
                            array_push($params, $data[$var_name]);
                        }
                    } else {
                        array_push($params, $var_name);
                    }
                }
                $data_title = call_user_func_array($record['list_func']['name'], $params);
            } else {
                $data_title = '';
            }
            
            //prepare obligatory mark
            if ($record['not_empty']) {
                $not_empty = '<span class="star">*</span>';
            } else {
                $not_empty = '';
            }
            
            //prepare examples
            $examples = '';
            if (is_array($record['examples'])) {
                if (!is_array(reset($record['examples']))) {
                    $record['examples'] = array($record['examples']);
                }
                foreach($record['examples'] as $example) {
                    if (strlen($examples)) {
                        $examples .= ', ';
                    }
                    $examples .= 
<<<HTML
<span class="eg" onClick="document.form_content.{$record['name_form']}.value='{$example['value']}'">{$example['title']}</span>
HTML;
                }
            }
                
            //select
            $record['opt_values'] = array();
            $record['opt_titles'] = array();
            if (isset($record['selectbox'])) {
                foreach ($record['selectbox']['option'] as $key => $option) {
                    array_push($record['opt_values'], $record['selectbox']['option'][$key]['opt_value']);
                    array_push($record['opt_titles'], $record['selectbox']['option'][$key]['opt_title']);
                }
            }
            
            //size
            if (!isset($record['size'])) {
                $record['size'] = 1;
            }

            if ($record['translatable']) {

                $HTML .=
<<<HTML
    <div class="divider">
        <span class="title" id="title_{$record['name_form']}">{$record['title']}{$not_empty}</span>
        <small class="help-trans">{$record['title_help']}</small>
HTML;
                foreach ($langs as $lang_id => $lang_title) {
                    $args = array(
                        'type'       => $record['input_type'],
                        'name'       => $record['name_form'] . '_' . $lang_id,
                        'value'      => $data[$record['name_dbase']][$lang_id],
                        'class'      => $record['css_class'],
                        'events'     => $record['js_events'],
                        'readonly'   => $record['readonly'],
                        'title'      => $data_title,
                        'sel_titles' => $record['opt_titles'],
                        'sel_values' => $record['opt_values'],
                        'size'       => $record['size']
                    );
                    $input = call_user_func_array('form_input', $args);
                    $HTML .=
<<<HTML
        <label for="" class="lang">{$lang_title}</label>
        <div class="container">$input</div>
HTML;
                }
                $HTML .=
<<<HTML
    </div>
HTML;
            } else {
                $args = array(
                    'type'       => $record['input_type'],
                    'name'       => $record['name_form'],
                    'value'      => $data[$record['name_dbase']],
                    'class'      => $record['css_class'],
                    'events'     => $record['js_events'],
                    'readonly'   => $record['readonly'],
                    'title'      => $data_title,
                    'sel_titles' => $record['opt_titles'],
                    'sel_values' => $record['opt_values'],
                    'size'       => $record['size']
                );
                $input = call_user_func_array('form_input', $args);
                $html_examples = strlen($examples) ? '(' . $examples . ')' : '';
                $HTML .= 
<<<HTML
    <div class="divider">
        <label for="" class="title" id="title_{$record['name_form']}">{$record['title']}{$not_empty}</label>
        <small class="help">{$record['title_help']}</small>
        <div class="container">{$input} {$html_examples}</div>
    </div>
HTML;
            }
        }
        }
        $HTML .=
<<<HTML
    </dd>
HTML;
    }
        $HTML .=
<<<HTML
    </dl>
HTML;
    
    $HTML_BUTTONS = '<div class="buttons">';
    foreach($buttons as $button) {
        if (is_array($button['js_events']) && !is_array(reset($button['js_events']))) {
            $button['js_events'] = array($button['js_events']);
        }
        $args = array(
            'type'   => ($button['type'] == 'button') ? 'image' : $button['type'],
            'name'   => $button['name'],
            'title'  => $button['title'],
            'class'  => 'input-image',
            'events' => $button['js_events'],
            'value'  => $button['value'],
            'image'  => $GLOBALS['URL']['icons'] . $button['name'] . '.gif',
        );
        $HTML_BUTTONS .= '&nbsp;' . call_user_func_array('form_button', $args) . '&nbsp;';
    }
    
    $HTML_BUTTONS .=
<<<HTML
    </div>
    <input type="hidden" name="changed" />
HTML;


    $HTML = '<form name="form_content" id="form-content" method="post" enctype="multipart/form-data">' . $HTML_BUTTONS . $HTML . '</form>';
    echo $HTML;
}

/*
    generates list
    receives data, data structure, language ID
    returnes nothing
*/
function makeList($data, $data_struct, $buttons, $contextmenu, $lang)
{
    global $Access;
    
    global $sys_lang_id;
    $langs = array();
    foreach ($GLOBALS['all_langs'] as $lang) {
        $langs[$lang['id']] = $lang['title'][$sys_lang_id];
    }
    
    $records_by_type = array();
    $records_by_name = array();
    foreach ($data_struct as $record) {
        $records_by_type[$record['type']][] = $record;
        $records_by_name[$record['name_dbase']] = $record;
    }

    $data_by_id = array();
    foreach ($data as $row) {
        $data_by_id[$row['id']] = $row;
    }
    
    $$GLOBALS['MODULE']['class_var'] = new $GLOBALS['MODULE']['class_name'];
    $fields = array();
    $sys_info = array();
    $HTML = '';

    $chk = form_input("checkbox", "check_main", 0, "input-checkbox", array(array('name'=>'onClick', 'value'=>'checkAll();markAll()')));
    $HTML .=
<<<HTML
<table class="table-builder-spreadsheet">
    <thead class="table-builder-spreadsheet">
        <tr>
            <td>$chk</td>
HTML;
    //fields in header
    foreach ($data_struct as $record) {
        if ($record['show_list']) {
            array_push($fields, $record['name_dbase']);
            $HTML .=
<<<HTML
            <th onDblClick="doOrder()" id="sort_{$record['name_dbase']}">{$record['title']}</th>
HTML;
        } else if ($record['type'] == 'system') {
            array_push($sys_info, $record['name_dbase']);
        }

        if (isset($record['list_func'])) {
            $list_func[$record['name_dbase']]['func_name'] = $record['list_func']['name'];
            $list_func[$record['name_dbase']]['params'] = array();

            if (!is_array($record['list_func']['params'])) {
                $record['list_func']['params'] = array($record['list_func']['params']);
            }
            foreach($record['list_func']['params'] as $param_name) {
                array_push($list_func[$record['name_dbase']]['params'], $param_name);
            }
        }
    }
    $HTML .=
<<<HTML
        </tr>
    </thead>
    <tbody class="table-builder-spreadsheet">
HTML;

    //output rows
    foreach ($data as $row) {
        $owner = $data_by_id[$row['id']]['owner'];
        $attr = $data_by_id[$row['id']]['attributes'];

        $args = array(
            'type' => 'checkbox',
            'name' => "check_{$row['id']}",
            'value' => 0,
            'class' => 'input-checkbox',
            'events' => array(array('name'=>'onClick', 'value'=>"markRow({$row['id']})"))
        );
        $chk = call_user_func_array('form_input', $args);
        
//        if($Access->is_allowed($owner, $attr, VIEW))
        {
            $HTML .=
<<<HTML
        <tr id="tr_{$row['id']}" onDblClick="doEdit('{$row['id']}')">
            <td>
            $chk
HTML;
                    $HTML.=
<<<HTML
<div class="div-system-info" id="sysinfo_{$row['id']}">
HTML;
                    foreach($sys_info as $sys_field) {
                        if (!is_array($row[$sys_field])) {
                            $sys_value=$row[$sys_field];
                        } else {
                            $sys_value=$row[$sys_field][$lang];
                        }
                        
                        //if list function defined
                        if (isset($list_func[$sys_field])) {
                            $params = array();
                            foreach ($list_func[$sys_field]['params'] as $var_name) {
                                if (isset($row[$var_name])) {
                                    if (!is_array($row[$var_name])) {
                                        array_push($params, $row[$var_name]);
                                    } else {
                                        array_push($params, $row[$var_name][$lang]);
                                    }
                                } else {
                                    array_push($params, $var_name);
                                }
                            }
                            $sys_value = call_user_func_array($list_func[$sys_field]['func_name'], $params);
                        }
                        
                        $HTML .=
<<<HTML
{$GLOBALS['LANG']['field'][$sys_field]}: {$sys_value}<br />
HTML;
                    }
                    $attributes = atrb2str($row['attributes']);
                    $HTML .=
<<<HTML
{$GLOBALS['LANG']['label']['attributes']}: $attributes
</div>
<ul class="menu-builder-dropdown" id="contextmenu_{$row['id']}">
HTML;
            foreach($contextmenu as $item)
            {
                $js_ev = '';
                if (!isset($item['action']) || (isset($item['action'])
                 && $Access->is_allowed($owner, $attr, $item['action']))) {
                    $css_class = 'contextmenu';
                    $image = ($item['icon']) ? "<img src=\"{$item['icon']}\">" : '';
                    if (!is_array(reset($item['js_events']))) {
                        $item['js_events']=array($item['js_events']);
                    }
                    foreach($item['js_events'] as $event) {
                        $js_ev .=' ' . $event['name'] . '="' . $event['value'] . '"';
                    }
                } else {
                    $css_class = 'contextmenu-off';
                    $image = ($item['icon-disabled']) ? "<img src=\"{$item['icon-disabled']}\">" : '';
                    $js_ev = '';
                }
//~{$item['name']}?id={$row['id']}
                $HTML .=
<<<HTML
    <li class="menu-builder-dropdown">
        <a href="javascript: void(0);"{$js_ev} class="menu-builder-dropdown contextmenu-{$item['name']}" id="{$item['name']}_{$row['id']}">{$item['title']}</a>
        <input type="hidden" name="{$item['name']}_{$row['id']}_value" value="{$row['id']}" />
    </li>
HTML;
            }
        $HTML.=
<<<HTML
</ul>
</td>
HTML;

            //system info
            $is_first = true;
            foreach ($fields as $field) {
                if ($is_first && $field != 'id') {
                    $HTML_Ev =
<<<HTML
 onMouseover="ShowLocate('sysinfo_{$row['id']}', event)" onMouseout="Hide('sysinfo_{$row['id']}')"
HTML;
                } else {
                    $HTML_Ev = '';
                }
                //data
                if (!is_array($row[$field])) {
                    $value = $row[$field];
                } else {
                    $value = $row[$field][$sys_lang_id];
                }
                $value4filter = htmlspecialchars($value, ENT_QUOTES);
                $value4filter = nl2br($value4filter);
                $value4filter = str_replace("\r\n", '\n', $value4filter);

                //if list function defined
                if (isset($list_func[$field])) {
                    $params = array();
                    if (!is_array($list_func[$field]['params'])) {
                        $list_func[$field]['params'] = array($list_func[$field]['params']);
                    }
                    foreach ($list_func[$field]['params'] as $var_name) {
                        if (isset($row[$var_name])) {
                            if (!is_array($row[$var_name])) {
                                array_push($params, $row[$var_name]);
                            } else {
                                array_push($params, $row[$var_name][$sys_lang_id]);
                            }
                        } else {
                            array_push($params, $var_name);
                        }
                    }
                    $value = call_user_func_array($list_func[$field]['func_name'], $params);
                }

                $td_css_class = ($field=='id') ? 'td-id' : 'td-content';
                $HTML .=
<<<HTML
            <td onClick="doMark({$row['id']})" onMousedown="hideContextMenu(); showContextMenu('{$row['id']}', event)">
                <span onClick="setFilter('$field', '$value4filter')" class="arrow"{$HTML_Ev}>$value</span>
            </td>
HTML;
                if ($field != 'id') {
                    $is_first = false;
                }
            }
            $HTML .=
<<<HTML
        </tr>
HTML;
        }
    }

    $pages = block_pages();
    $perpage = block_perpage();
    $search = block_search();
    
    $HTML .=
<<<HTML
    </tbody>
    <tfoot class="table-builder-spreadsheet">
        <tr id="space">
            <td colspan="100"></td>
        </tr>
        <tr id="pages">
            <td colspan="100">{$pages}</td>
        </tr>
        <tr id="perpage">
            <td colspan="100">{$perpage}</td>
        </tr>
        <tr id="search">
            <td colspan="100">
                {$search}
            </td>
        </tr>
    </tfoot>
</table>
HTML;

    //output buttons
    $colspan = count($fields)+1;
    $HTML_BUTTONS =
<<<HTML
  <div class="buttons">
HTML;
    foreach($buttons as $button)
    {
        if (is_array($button['js_events']) && !is_array(reset($button['js_events']))) {
            $button['js_events'] = array($button['js_events']);
        }
        $args = array(
            'type'   => 'image',//$button['type'],
            'name'   => $button['name'],
            'title'  => $button['title'],
            'class'  => 'input-image',
            'events' => $button['js_events'],
            'value'  => $button['value'],
            'image'  => $GLOBALS['URL']['icons'] . $button['name'] . '.png',
        );
        $HTML_BUTTONS .= ' ' . call_user_func_array('form_button', $args) . ' ';
    }
    $HTML_BUTTONS .=
<<<HTML
</div>
<input type="hidden" id="ctmenu_showed" value="0" />
HTML;

    $HELP = '<div id="help">' . $GLOBALS['LANG']['label']['edit_hint'] . '</div>';

    echo '<form name="form_content" method="post" action="?list" onContextmenu="return false">' . $HTML_BUTTONS . $HELP . $HTML . '</form>';
}

/*
    generates item view page
    receives data, data structure, buttons structure, language ID
    returnes nothing
*/
function makeView($data, $data_struct, $buttons_bottom, $lang)
{
    $Lang = new TBL_Lang;
    function getByName($data_struct, $name)
    {
        //gets record by name
        foreach ($data_struct as $record) {
            if ($record['name_dbase']==$name) {
                return $record;
            }
        }
         return null;
    }
    $lang=$Lang->id_by_name($_SESSION[$GLOBALS['MODULE']['name'] . 'sys_lang']);

    $fields = array();

    //output header
    $HTML=
<<<HTML
<table class="table-content">
  <tr class="tr-header">
HTML;

    //output fields
    foreach ($data as $field => $value) {
        $record = getByName($data_struct, $field);
        if ($record['show_view']) {   	
            $title = getVar($record, 'title');
            $HTML .=
<<<HTML
  <tr class="tr-content">
    <td class="td-title" width="20%">$title:</td>
HTML;
            if (is_array($value)) {
            	$value = $value[$lang];
            }
        	if (isset($record['view_func']) && $record['view_func']) {
        		$params = array();
        		if (!is_array($record['view_func']['params'])) {
        			$record['view_func']['params'] = array($record['view_func']['params']);
        		}
        		foreach ($record['view_func']['params'] as $param) {
        			array_push($params, $data[$param]);
        		}
        		$value = call_user_func_array($record['view_func']['name'], $params);
        	}
                $HTML.=
<<<HTML
    <td class="td-content" width="80%">$value</td>
HTML;
            $HTML .=
<<<HTML
  </tr>
HTML;
        }
    }
    //output buttons
    $HTML .=
<<<HTML
<tr class="tr-buttons">
  <td class="td-buttons" colspan="2">
HTML;
    foreach ($buttons_bottom as $button) {
        if (is_array($button['js_events']) && !is_array(reset($button['js_events']))) {
        	$button['js_events']=array($button['js_events']);
        }
        $HTML .= "
    ".form_button($button['type'], $button['name'], $button['title'], $button['css_class'], $button['js_events'], $button['value']);
    }
    $HTML .=
<<<HTML
  </td>
</tr>
</table>
HTML;
    echo $HTML;
}

/*
    outputs pages block
    receives settings to pass through GET
    returnes HTML code of the block
*/
function block_pages()
{
    $HTML = '';

    $prev = $_SESSION[$GLOBALS['MODULE']['name'] . 'sys_page'] - 1;
    $next = $_SESSION[$GLOBALS['MODULE']['name'] . 'sys_page'] + 1;
    $pages = ceil($GLOBALS['num'] / $_SESSION[$GLOBALS['MODULE']['name'] . 'sys_perpage']);

    if ($pages > 0) {
        $HTML .=
<<<HTML
<div id="pages">
    <div class="pages">
        <a href="?sys_page=1" class="page"><img src="{$GLOBALS['URL']['themes']}{$GLOBALS['CONF']['theme']}/buttons/first.gif" border="0" alt="{$GLOBALS['LANG']['label']['first']} {$GLOBALS['LANG']['label']['page']}"></a>
        <a href="?sys_page=$prev" class="page"><img src="{$GLOBALS['URL']['themes']}{$GLOBALS['CONF']['theme']}/buttons/previous.gif" border="0" alt="{$GLOBALS['LANG']['label']['previous']} {$GLOBALS['LANG']['label']['page']}"></a>
HTML;

        for ($i = 1; $i <= $pages; $i ++) {
            if ($i != $_SESSION[$GLOBALS['MODULE']['name'] . 'sys_page']) {
                $HTML .=
<<<HTML
        <a href="?sys_page=$i" class="page">$i</a> 
HTML;
            } else {
                $HTML .=
<<<HTML
        <strong>[$i]</strong> 
HTML;
            }
        }
        $HTML .=
<<<HTML
        <a href="?sys_page=$next" class="page"><img src="{$GLOBALS['URL']['themes']}{$GLOBALS['CONF']['theme']}/buttons/next.gif" border="0" alt="{$GLOBALS['LANG']['label']['next']} {$GLOBALS['LANG']['label']['page']}"></a>
        <a href="?sys_page=$pages" class="page"><img src="{$GLOBALS['URL']['themes']}{$GLOBALS['CONF']['theme']}/buttons/last.gif" border="0" alt="{$GLOBALS['LANG']['label']['last']} {$GLOBALS['LANG']['label']['page']}"></a>
    </div>
    <div class="total">{$GLOBALS['LANG']['label']['total_pages']}: $pages</div>
</div>
HTML;
    }
    return $HTML;
}

/*
    outputs filter block
    receives settings to pass through GET
    returnes HTML code of the block
*/
function block_search()
{
    $sys_fvalue = stripslashes($_SESSION[$GLOBALS['MODULE']['name'] . 'sys_fvalue']);
    if (!empty($_SESSION[$GLOBALS['MODULE']['name'] . 'sys_ffield']) && strlen($_SESSION[$GLOBALS['MODULE']['name'] . 'sys_fvalue'])) {
        $fquery = "{$_SESSION[$GLOBALS['MODULE']['name'] . 'sys_ffield']} = {$_SESSION[$GLOBALS['MODULE']['name'] . 'sys_fvalue']}";
    } else {
        $fquery = '';
    }
    $HTML =
<<<HTML
<div>
    <label for="sys-search">{$GLOBALS['LANG']['label']['search']}:</label>
    <input type="text" id="sys-search" name="sys_svalue" value="{$_SESSION[$GLOBALS['MODULE']['name'] . 'sys_svalue']}" class="text" size="50" />
    <input type="button" class="input-button" value="{$GLOBALS['LANG']['button']['show']}"
     onClick="Go('?sys_svalue=' + document.getElementsByName('sys_svalue')[0].value + '&sys_ffield=' + document.getElementsByName('sys_ffield')[0].value + '&sys_fvalue=' + document.getElementsByName('sys_fvalue')[0].value);" />
</div>
<div>
    <label for="sys-filter">{$GLOBALS['LANG']['label']['filter']}:</label>
    <input type="text" name="fquery" value="$fquery" class="text" size="30" readonly="readonly" />
    <input type="hidden" name="sys_ffield" value="{$_SESSION[$GLOBALS['MODULE']['name'] . 'sys_ffield']}" />
    <input type="hidden" name="sys_fvalue" value="{$_SESSION[$GLOBALS['MODULE']['name'] . 'sys_fvalue']}" />
    <img src="{$GLOBALS['URL']['themes']}{$GLOBALS['CONF']['theme']}/buttons/clear.gif" alt="x" class="input-image" onClick="clearFilter()" />
    ({$GLOBALS['LANG']['label']['filter_hint']})
</div>
HTML;

    return $HTML;
}

/*
    outputs per-page block
    receives settings to pass through GET
    returnes HTML code of the block
*/
function block_perpage()
{
    $total = $GLOBALS['num'];
    $page = $_SESSION[$GLOBALS['MODULE']['name'] . 'sys_page'];
    if ($page <= 0) {
        $page = 1;
    }
    $perpage = $_SESSION[$GLOBALS['MODULE']['name'] . 'sys_perpage'];
    $pages = ceil($total / $page);
    $start = ($page - 1) * $perpage + 1;
    $end = $start + ($page != $pages ? $perpage : $total % $perpage) - 1;
    
    $HTML =
<<<HTML
<div class="form">
    <label for="sys-perpage">{$GLOBALS['LANG']['label']['perpage']}:</label>
    <input type="text" id="sys-perpage" name="sys_perpage" value="{$perpage}" class="text" size="2" />
    <input type="button" value="{$GLOBALS['LANG']['button']['show']}" class="input-button" onClick="Go('?sys_perpage=' + document.getElementsByName('sys_perpage')[0].value)" />
</div>
<div class="total">{$GLOBALS['LANG']['label']['total_number']}: $start-$end ($total)</p>
HTML;

    return $HTML;
}

function module_short_text($text)
{
    return txt2short(strip_tags($text), 25, 's') . '...';
}
?>