<?php
//module.func.php - modules common functions

//mixed getFormData(array data_struct)
//mixed getDefaultData(array data_struct)
//bool checkData(array data, array data_struct)
//string report_empty(string title)
//string js_error(array names)
//void report_errors(array errors)
//void output_js(array lines)
//void goLocation(string url)

function getFormData($data_struct)
{
    //gets form data, passed over POST or GET methods
    //receives data structure
    //returnes associative array of data
    $Lang=new TBL_Lang;
    $data=array();
    $langs=$Lang->all();

    $attr=array(
                'owner'=>array('view', 'edit', 'delete'),
                'group'=>array('view', 'edit', 'delete'),
                'public'=>array('view', 'edit', 'delete'),
                );

    //general data
    foreach($data_struct as $record) {
     	if($record['name_form'] == 'attributes') {
       		$attr_dec='';
       		foreach($attr as $key => $user)
       		{
       			$attr_bin='';
       			foreach($user as $action)
       			$attr_bin=((getFormVar('attr_'.$key.'_'.$action, 0)) ? '1' : '0').$attr_bin;
       			$attr_dec.=bindec($attr_bin);
       		}
       		$data['attributes']=$attr_dec;
        } else {
            if(!$record['translatable']) {
            	switch ($record['input_type']) {
            	    case 'text':
            	        $data[$record['name_dbase']] = str_replace('"', '&quot;', getFormVar($record['name_form']));
            	        break;
            		case 'checkbox':
	                    $data[$record['name_dbase']] = (bool)getFormVar($record['name_form']);
	                    break;
	                case 'file': case 'image':
	                    $data[$record['name_dbase']] = getVar($_FILES, $record['name_form']);
	                	break;
	                default:
	                    $data[$record['name_dbase']] = getFormVar($record['name_form']);
            	}
            } else {
                foreach($langs as $lang_id) {
                	switch ($record['input_type']) {
                	    case 'text':
                	        $data[$record['name_dbase']][$lang_id] = str_replace('"', '&quot;', getFormVar($record['name_form'].'_'.$lang_id));
                	        break;
                		case 'checkbox':
	                        $data[$record['name_dbase']][$lang_id]=(bool)getFormVar($record['name_form'].'_'.$lang_id);
                			break;
                		case 'file': case 'image':
	                        $data[$record['name_dbase']][$lang_id]=getVar($_FILES, $record['name_form'].'_'.$lang_id);
                			break;
                		default:
	                        $data[$record['name_dbase']][$lang_id]=getFormVar($record['name_form'].'_'.$lang_id);
                	}
                }
            }
        }
    }
    return $data;
}

function getDefaultData($data_struct)
{
    //sets default data
    //receives data structure
    //returnes associative array of data
    $Lang=new TBL_Lang;
    $data=array();
    $langs=$Lang->all();
    foreach($data_struct as $record)
        if(!$record['translatable'])
            $data[$record['name_dbase']]=$record['default'];
        else
            foreach($langs as $lang_id)
                $data[$record['name_dbase']][$lang_id]=$record['default'];
    return $data;
}

function checkData($data, $data_struct, &$errors, &$js_react)
{
    //checks data
    //receives data, data structure
    //returnes true if data is ok, false otherwise
    $Lang=new TBL_Lang;
    $langs=$Lang->all();
    $errors=array();
    $js_react=array();
    foreach($data_struct as $record)
    {
        //test data that supposed to be not empty
        if($record['not_empty'])
            if(!$record['translatable'])
            {
                if(!$data[$record['name_dbase']])
                {
                    array_push($errors, report_empty($record['title']));
                    array_push($js_react, js_error($record['name_form']));
                }
            }
            else
            {
                $test=false;
                foreach($langs as $lang_id)
                    if($data[$record['name_dbase']][$lang_id])
                    {
                        $test=true;
                        break;
                    }
                if(!$test)
                {
                    array_push($errors, report_empty($record['title']));
                    array_push($js_react, js_error($record['name_form']));
                }
            }

        //test data with user defined test functions
        if(isset($record['test_func']))
        {
            $func_name=$record['test_func']['name'];
            $params=array();
            if (!is_array($record['test_func']['params'])) {
                $record['test_func']['params'] = array($record['test_func']['params']);
            }
            foreach($record['test_func']['params'] as $var_name)
                array_push($params, $data[$var_name]);

            $error=call_user_func_array($func_name, $params);
            if($error)
            {
                array_push($errors, $error);
                array_push($js_react, js_error($record['name_form']));
            }
        }
    }
    if(count($errors)) return false;
    else return true;
}

function report_empty($title)
{
    //generates error with given title
    //receives title
    //returnes error message
    $error_msg = "$title " . $GLOBALS['LANG']['error']['is_missing'];
    return $error_msg;
}

function js_error($name)
{
    //generates JavaScript reaction on error
    //receives input name
    //returnes string - JavaScript line
    $js_react = "document.getElementById('title_$name').className='title-highlight'";
    return $js_react;
}

function report_errors($errors)
{
    //output error messages
    //receives array of messages
    //returnes nothing
    echo "<div class=error>";
    foreach ($errors as $n => $error) {
        echo ($n ? '<br />' : '') . $error;
    }
    echo "</div>";
}

function output_js($lines)
{
    //output JavaScript
    //receives array of lines
    //returnes nothing
    echo "<script language=\"JavaScript\" type=\"text/javascript\">";
    foreach($lines as $line)
        echo "\n$line";
    echo "</script>";
}

?>